@@ -3,10 +3,11 @@ from decimal import Decimal
 from operator import itemgetter
 
 from django import forms
-from django.contrib import admin
+from django.contrib import admin, messages
 from django.contrib.admin import widgets
 from django.contrib.admin.options import csrf_protect_m
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns, url
+from django.core.exceptions import PermissionDenied
 from django.forms import fields
 from django.http import HttpResponseRedirect
 from django.shortcuts import render_to_response
@@ -20,7 +21,7 @@ from constance import config, settings
 NUMERIC_WIDGET = forms.TextInput(attrs={'size': 10})
 
 INTEGER_LIKE = (fields.IntegerField, {'widget': NUMERIC_WIDGET})
-STRING_LIKE = (fields.CharField, {'widget': forms.Textarea(attrs={'rows': 3})})
+STRING_LIKE = (fields.CharField, {'widget': forms.Textarea(attrs={'rows': 3}), 'required': False})
 
 FIELDS = {
     bool: (fields.BooleanField, {'required': False}),
@@ -66,6 +67,8 @@ class ConstanceAdmin(admin.ModelAdmin):
     @csrf_protect_m
     def changelist_view(self, request, extra_context=None):
         # First load a mapping between config name and default value
+        if not self.has_change_permission(request, None):
+            raise PermissionDenied
         default_initial = ((name, default)
             for name, (default, help_text) in settings.CONFIG.iteritems())
         # Then update the mapping with actually values from the backend
@@ -76,7 +79,12 @@ class ConstanceAdmin(admin.ModelAdmin):
             form = ConstanceForm(request.POST)
             if form.is_valid():
                 form.save()
-                self.message_user(request, _('Live settings updated successfully.'))
+                # In django 1.5 this can be replaced with self.message_user
+                messages.add_message(
+                    request,
+                    messages.SUCCESS,
+                    _('Live settings updated successfully.'),
+                )
                 return HttpResponseRedirect('.')
         context = {
             'config': [],
@@ -111,20 +119,25 @@ class ConstanceAdmin(admin.ModelAdmin):
     def has_delete_permission(self, *args, **kwargs):
         return False
 
-    def has_change_permission(self, request, obj=None, *args, **kwargs):
-        if request.user.is_superuser:
-            return True
+    def has_change_permission(self, request, obj=None):
+        if settings.SUPERUSER_ONLY:
+            return request.user.is_superuser
         else:
-            return False
+            return super(ConstanceAdmin, self).has_change_permission(request, obj)
 
 
 class Config(object):
     class Meta(object):
         app_label = 'constance'
-        module_name = 'config'
+        model_name = module_name = 'config'
         verbose_name_plural = 'config'
         get_ordered_objects = lambda x: False
         abstract = False
+        swapped = False
+
+        def get_change_permission(self):
+            return 'change_%s' % self.model_name
+
     _meta = Meta()
 
 
