@@ -5,8 +5,8 @@ settings = import_module_attr(
     os.getenv('CONSTANCE_SETTINGS_MODULE', 'django.conf.settings')
 )
 
-PREFIX = getattr(settings, 'CONSTANCE_REDIS_PREFIX',
-         getattr(settings, 'CONSTANCE_PREFIX', 'constance:'))
+REDIS_PREFIX = getattr(settings, 'CONSTANCE_REDIS_PREFIX',
+               getattr(settings, 'CONSTANCE_PREFIX', 'constance:'))
 
 BACKEND = getattr(settings, 'CONSTANCE_BACKEND', 'constance.backends.redisd.RedisBackend')
 
@@ -20,3 +20,7 @@ REDIS_CONNECTION = getattr(settings, 'CONSTANCE_REDIS_CONNECTION',
 
 DATABASE_CACHE_BACKEND = getattr(settings, 'CONSTANCE_DATABASE_CACHE_BACKEND',
                                  None)
+
+DATABASE_PREFIX = getattr(settings, 'CONSTANCE_DATABASE_PREFIX', '')
+
+SUPERUSER_ONLY = getattr(settings, 'CONSTANCE_SUPERUSER_ONLY', True)
